//! Tests auto-converted from "sass-spec/spec/libsass/color-functions/rgb/rgb/g.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("g")
}

#[test]
fn test() {
    assert_eq!(
        runner().ok("foo {\
             \n  c-1: rgb(0,-1,0);\
             \n  c0: rgb(0,0,0);\
             \n  c1: rgb(0,1,0);\
             \n  c2: rgb(0,2,0);\
             \n  c3: rgb(0,3,0);\
             \n  c4: rgb(0,4,0);\
             \n  c5: rgb(0,5,0);\
             \n  c6: rgb(0,6,0);\
             \n  c7: rgb(0,7,0);\
             \n  c8: rgb(0,8,0);\
             \n  c9: rgb(0,9,0);\
             \n  c10: rgb(0,10,0);\
             \n  c11: rgb(0,11,0);\
             \n  c12: rgb(0,12,0);\
             \n  c13: rgb(0,13,0);\
             \n  c14: rgb(0,14,0);\
             \n  c15: rgb(0,15,0);\
             \n  c16: rgb(0,16,0);\
             \n  c17: rgb(0,17,0);\
             \n  c18: rgb(0,18,0);\
             \n  c19: rgb(0,19,0);\
             \n  c20: rgb(0,20,0);\
             \n  c21: rgb(0,21,0);\
             \n  c22: rgb(0,22,0);\
             \n  c23: rgb(0,23,0);\
             \n  c24: rgb(0,24,0);\
             \n  c25: rgb(0,25,0);\
             \n  c26: rgb(0,26,0);\
             \n  c27: rgb(0,27,0);\
             \n  c28: rgb(0,28,0);\
             \n  c29: rgb(0,29,0);\
             \n  c30: rgb(0,30,0);\
             \n  c31: rgb(0,31,0);\
             \n  c32: rgb(0,32,0);\
             \n  c33: rgb(0,33,0);\
             \n  c34: rgb(0,34,0);\
             \n  c35: rgb(0,35,0);\
             \n  c36: rgb(0,36,0);\
             \n  c37: rgb(0,37,0);\
             \n  c38: rgb(0,38,0);\
             \n  c39: rgb(0,39,0);\
             \n  c40: rgb(0,40,0);\
             \n  c41: rgb(0,41,0);\
             \n  c42: rgb(0,42,0);\
             \n  c43: rgb(0,43,0);\
             \n  c44: rgb(0,44,0);\
             \n  c45: rgb(0,45,0);\
             \n  c46: rgb(0,46,0);\
             \n  c47: rgb(0,47,0);\
             \n  c48: rgb(0,48,0);\
             \n  c49: rgb(0,49,0);\
             \n  c50: rgb(0,50,0);\
             \n  c51: rgb(0,51,0);\
             \n  c52: rgb(0,52,0);\
             \n  c53: rgb(0,53,0);\
             \n  c54: rgb(0,54,0);\
             \n  c55: rgb(0,55,0);\
             \n  c56: rgb(0,56,0);\
             \n  c57: rgb(0,57,0);\
             \n  c58: rgb(0,58,0);\
             \n  c59: rgb(0,59,0);\
             \n  c60: rgb(0,60,0);\
             \n  c61: rgb(0,61,0);\
             \n  c62: rgb(0,62,0);\
             \n  c63: rgb(0,63,0);\
             \n  c64: rgb(0,64,0);\
             \n  c65: rgb(0,65,0);\
             \n  c66: rgb(0,66,0);\
             \n  c67: rgb(0,67,0);\
             \n  c68: rgb(0,68,0);\
             \n  c69: rgb(0,69,0);\
             \n  c70: rgb(0,70,0);\
             \n  c71: rgb(0,71,0);\
             \n  c72: rgb(0,72,0);\
             \n  c73: rgb(0,73,0);\
             \n  c74: rgb(0,74,0);\
             \n  c75: rgb(0,75,0);\
             \n  c76: rgb(0,76,0);\
             \n  c77: rgb(0,77,0);\
             \n  c78: rgb(0,78,0);\
             \n  c79: rgb(0,79,0);\
             \n  c80: rgb(0,80,0);\
             \n  c81: rgb(0,81,0);\
             \n  c82: rgb(0,82,0);\
             \n  c83: rgb(0,83,0);\
             \n  c84: rgb(0,84,0);\
             \n  c85: rgb(0,85,0);\
             \n  c86: rgb(0,86,0);\
             \n  c87: rgb(0,87,0);\
             \n  c88: rgb(0,88,0);\
             \n  c89: rgb(0,89,0);\
             \n  c90: rgb(0,90,0);\
             \n  c91: rgb(0,91,0);\
             \n  c92: rgb(0,92,0);\
             \n  c93: rgb(0,93,0);\
             \n  c94: rgb(0,94,0);\
             \n  c95: rgb(0,95,0);\
             \n  c96: rgb(0,96,0);\
             \n  c97: rgb(0,97,0);\
             \n  c98: rgb(0,98,0);\
             \n  c99: rgb(0,99,0);\
             \n  c100: rgb(0,100,0);\
             \n  c101: rgb(0,101,0);\
             \n  c102: rgb(0,102,0);\
             \n  c103: rgb(0,103,0);\
             \n  c104: rgb(0,104,0);\
             \n  c105: rgb(0,105,0);\
             \n  c106: rgb(0,106,0);\
             \n  c107: rgb(0,107,0);\
             \n  c108: rgb(0,108,0);\
             \n  c109: rgb(0,109,0);\
             \n  c110: rgb(0,110,0);\
             \n  c111: rgb(0,111,0);\
             \n  c112: rgb(0,112,0);\
             \n  c113: rgb(0,113,0);\
             \n  c114: rgb(0,114,0);\
             \n  c115: rgb(0,115,0);\
             \n  c116: rgb(0,116,0);\
             \n  c117: rgb(0,117,0);\
             \n  c118: rgb(0,118,0);\
             \n  c119: rgb(0,119,0);\
             \n  c120: rgb(0,120,0);\
             \n  c121: rgb(0,121,0);\
             \n  c122: rgb(0,122,0);\
             \n  c123: rgb(0,123,0);\
             \n  c124: rgb(0,124,0);\
             \n  c125: rgb(0,125,0);\
             \n  c126: rgb(0,126,0);\
             \n  c127: rgb(0,127,0);\
             \n  c128: rgb(0,128,0);\
             \n  c129: rgb(0,129,0);\
             \n  c130: rgb(0,130,0);\
             \n  c131: rgb(0,131,0);\
             \n  c132: rgb(0,132,0);\
             \n  c133: rgb(0,133,0);\
             \n  c134: rgb(0,134,0);\
             \n  c135: rgb(0,135,0);\
             \n  c136: rgb(0,136,0);\
             \n  c137: rgb(0,137,0);\
             \n  c138: rgb(0,138,0);\
             \n  c139: rgb(0,139,0);\
             \n  c140: rgb(0,140,0);\
             \n  c141: rgb(0,141,0);\
             \n  c142: rgb(0,142,0);\
             \n  c143: rgb(0,143,0);\
             \n  c144: rgb(0,144,0);\
             \n  c145: rgb(0,145,0);\
             \n  c146: rgb(0,146,0);\
             \n  c147: rgb(0,147,0);\
             \n  c148: rgb(0,148,0);\
             \n  c149: rgb(0,149,0);\
             \n  c150: rgb(0,150,0);\
             \n  c151: rgb(0,151,0);\
             \n  c152: rgb(0,152,0);\
             \n  c153: rgb(0,153,0);\
             \n  c154: rgb(0,154,0);\
             \n  c155: rgb(0,155,0);\
             \n  c156: rgb(0,156,0);\
             \n  c157: rgb(0,157,0);\
             \n  c158: rgb(0,158,0);\
             \n  c159: rgb(0,159,0);\
             \n  c160: rgb(0,160,0);\
             \n  c161: rgb(0,161,0);\
             \n  c162: rgb(0,162,0);\
             \n  c163: rgb(0,163,0);\
             \n  c164: rgb(0,164,0);\
             \n  c165: rgb(0,165,0);\
             \n  c166: rgb(0,166,0);\
             \n  c167: rgb(0,167,0);\
             \n  c168: rgb(0,168,0);\
             \n  c169: rgb(0,169,0);\
             \n  c170: rgb(0,170,0);\
             \n  c171: rgb(0,171,0);\
             \n  c172: rgb(0,172,0);\
             \n  c173: rgb(0,173,0);\
             \n  c174: rgb(0,174,0);\
             \n  c175: rgb(0,175,0);\
             \n  c176: rgb(0,176,0);\
             \n  c177: rgb(0,177,0);\
             \n  c178: rgb(0,178,0);\
             \n  c179: rgb(0,179,0);\
             \n  c180: rgb(0,180,0);\
             \n  c181: rgb(0,181,0);\
             \n  c182: rgb(0,182,0);\
             \n  c183: rgb(0,183,0);\
             \n  c184: rgb(0,184,0);\
             \n  c185: rgb(0,185,0);\
             \n  c186: rgb(0,186,0);\
             \n  c187: rgb(0,187,0);\
             \n  c188: rgb(0,188,0);\
             \n  c189: rgb(0,189,0);\
             \n  c190: rgb(0,190,0);\
             \n  c191: rgb(0,191,0);\
             \n  c192: rgb(0,192,0);\
             \n  c193: rgb(0,193,0);\
             \n  c194: rgb(0,194,0);\
             \n  c195: rgb(0,195,0);\
             \n  c196: rgb(0,196,0);\
             \n  c197: rgb(0,197,0);\
             \n  c198: rgb(0,198,0);\
             \n  c199: rgb(0,199,0);\
             \n  c200: rgb(0,200,0);\
             \n  c201: rgb(0,201,0);\
             \n  c202: rgb(0,202,0);\
             \n  c203: rgb(0,203,0);\
             \n  c204: rgb(0,204,0);\
             \n  c205: rgb(0,205,0);\
             \n  c206: rgb(0,206,0);\
             \n  c207: rgb(0,207,0);\
             \n  c208: rgb(0,208,0);\
             \n  c209: rgb(0,209,0);\
             \n  c210: rgb(0,210,0);\
             \n  c211: rgb(0,211,0);\
             \n  c212: rgb(0,212,0);\
             \n  c213: rgb(0,213,0);\
             \n  c214: rgb(0,214,0);\
             \n  c215: rgb(0,215,0);\
             \n  c216: rgb(0,216,0);\
             \n  c217: rgb(0,217,0);\
             \n  c218: rgb(0,218,0);\
             \n  c219: rgb(0,219,0);\
             \n  c220: rgb(0,220,0);\
             \n  c221: rgb(0,221,0);\
             \n  c222: rgb(0,222,0);\
             \n  c223: rgb(0,223,0);\
             \n  c224: rgb(0,224,0);\
             \n  c225: rgb(0,225,0);\
             \n  c226: rgb(0,226,0);\
             \n  c227: rgb(0,227,0);\
             \n  c228: rgb(0,228,0);\
             \n  c229: rgb(0,229,0);\
             \n  c230: rgb(0,230,0);\
             \n  c231: rgb(0,231,0);\
             \n  c232: rgb(0,232,0);\
             \n  c233: rgb(0,233,0);\
             \n  c234: rgb(0,234,0);\
             \n  c235: rgb(0,235,0);\
             \n  c236: rgb(0,236,0);\
             \n  c237: rgb(0,237,0);\
             \n  c238: rgb(0,238,0);\
             \n  c239: rgb(0,239,0);\
             \n  c240: rgb(0,240,0);\
             \n  c241: rgb(0,241,0);\
             \n  c242: rgb(0,242,0);\
             \n  c243: rgb(0,243,0);\
             \n  c244: rgb(0,244,0);\
             \n  c245: rgb(0,245,0);\
             \n  c246: rgb(0,246,0);\
             \n  c247: rgb(0,247,0);\
             \n  c248: rgb(0,248,0);\
             \n  c249: rgb(0,249,0);\
             \n  c250: rgb(0,250,0);\
             \n  c251: rgb(0,251,0);\
             \n  c252: rgb(0,252,0);\
             \n  c253: rgb(0,253,0);\
             \n  c254: rgb(0,254,0);\
             \n  c255: rgb(0,255,0);\
             \n  c256: rgb(0,256,0);\
             \n}\n\
             \nfoo {\
             \n  c-1: rgb(0,-1%,0);\
             \n  c0: rgb(0,0%,0);\
             \n  c1: rgb(0,1%,0);\
             \n  c2: rgb(0,2%,0);\
             \n  c3: rgb(0,3%,0);\
             \n  c4: rgb(0,4%,0);\
             \n  c5: rgb(0,5%,0);\
             \n  c6: rgb(0,6%,0);\
             \n  c7: rgb(0,7%,0);\
             \n  c8: rgb(0,8%,0);\
             \n  c9: rgb(0,9%,0);\
             \n  c10: rgb(0,10%,0);\
             \n  c11: rgb(0,11%,0);\
             \n  c12: rgb(0,12%,0);\
             \n  c13: rgb(0,13%,0);\
             \n  c14: rgb(0,14%,0);\
             \n  c15: rgb(0,15%,0);\
             \n  c16: rgb(0,16%,0);\
             \n  c17: rgb(0,17%,0);\
             \n  c18: rgb(0,18%,0);\
             \n  c19: rgb(0,19%,0);\
             \n  c20: rgb(0,20%,0);\
             \n  c21: rgb(0,21%,0);\
             \n  c22: rgb(0,22%,0);\
             \n  c23: rgb(0,23%,0);\
             \n  c24: rgb(0,24%,0);\
             \n  c25: rgb(0,25%,0);\
             \n  c26: rgb(0,26%,0);\
             \n  c27: rgb(0,27%,0);\
             \n  c28: rgb(0,28%,0);\
             \n  c29: rgb(0,29%,0);\
             \n  c30: rgb(0,30%,0);\
             \n  c31: rgb(0,31%,0);\
             \n  c32: rgb(0,32%,0);\
             \n  c33: rgb(0,33%,0);\
             \n  c34: rgb(0,34%,0);\
             \n  c35: rgb(0,35%,0);\
             \n  c36: rgb(0,36%,0);\
             \n  c37: rgb(0,37%,0);\
             \n  c38: rgb(0,38%,0);\
             \n  c39: rgb(0,39%,0);\
             \n  c40: rgb(0,40%,0);\
             \n  c41: rgb(0,41%,0);\
             \n  c42: rgb(0,42%,0);\
             \n  c43: rgb(0,43%,0);\
             \n  c44: rgb(0,44%,0);\
             \n  c45: rgb(0,45%,0);\
             \n  c46: rgb(0,46%,0);\
             \n  c47: rgb(0,47%,0);\
             \n  c48: rgb(0,48%,0);\
             \n  c49: rgb(0,49%,0);\
             \n  c50: rgb(0,50%,0);\
             \n  c51: rgb(0,51%,0);\
             \n  c52: rgb(0,52%,0);\
             \n  c53: rgb(0,53%,0);\
             \n  c54: rgb(0,54%,0);\
             \n  c55: rgb(0,55%,0);\
             \n  c56: rgb(0,56%,0);\
             \n  c57: rgb(0,57%,0);\
             \n  c58: rgb(0,58%,0);\
             \n  c59: rgb(0,59%,0);\
             \n  c60: rgb(0,60%,0);\
             \n  c61: rgb(0,61%,0);\
             \n  c62: rgb(0,62%,0);\
             \n  c63: rgb(0,63%,0);\
             \n  c64: rgb(0,64%,0);\
             \n  c65: rgb(0,65%,0);\
             \n  c66: rgb(0,66%,0);\
             \n  c67: rgb(0,67%,0);\
             \n  c68: rgb(0,68%,0);\
             \n  c69: rgb(0,69%,0);\
             \n  c70: rgb(0,70%,0);\
             \n  c71: rgb(0,71%,0);\
             \n  c72: rgb(0,72%,0);\
             \n  c73: rgb(0,73%,0);\
             \n  c74: rgb(0,74%,0);\
             \n  c75: rgb(0,75%,0);\
             \n  c76: rgb(0,76%,0);\
             \n  c77: rgb(0,77%,0);\
             \n  c78: rgb(0,78%,0);\
             \n  c79: rgb(0,79%,0);\
             \n  c80: rgb(0,80%,0);\
             \n  c81: rgb(0,81%,0);\
             \n  c82: rgb(0,82%,0);\
             \n  c83: rgb(0,83%,0);\
             \n  c84: rgb(0,84%,0);\
             \n  c85: rgb(0,85%,0);\
             \n  c86: rgb(0,86%,0);\
             \n  c87: rgb(0,87%,0);\
             \n  c88: rgb(0,88%,0);\
             \n  c89: rgb(0,89%,0);\
             \n  c90: rgb(0,90%,0);\
             \n  c91: rgb(0,91%,0);\
             \n  c92: rgb(0,92%,0);\
             \n  c93: rgb(0,93%,0);\
             \n  c94: rgb(0,94%,0);\
             \n  c95: rgb(0,95%,0);\
             \n  c96: rgb(0,96%,0);\
             \n  c97: rgb(0,97%,0);\
             \n  c98: rgb(0,98%,0);\
             \n  c99: rgb(0,99%,0);\
             \n  c100: rgb(0,100%,0);\
             \n  c101: rgb(0,101%,0);\
             \n}\n"),
        "foo {\
         \n  c-1: rgb(0, 0, 0);\
         \n  c0: rgb(0, 0, 0);\
         \n  c1: rgb(0, 1, 0);\
         \n  c2: rgb(0, 2, 0);\
         \n  c3: rgb(0, 3, 0);\
         \n  c4: rgb(0, 4, 0);\
         \n  c5: rgb(0, 5, 0);\
         \n  c6: rgb(0, 6, 0);\
         \n  c7: rgb(0, 7, 0);\
         \n  c8: rgb(0, 8, 0);\
         \n  c9: rgb(0, 9, 0);\
         \n  c10: rgb(0, 10, 0);\
         \n  c11: rgb(0, 11, 0);\
         \n  c12: rgb(0, 12, 0);\
         \n  c13: rgb(0, 13, 0);\
         \n  c14: rgb(0, 14, 0);\
         \n  c15: rgb(0, 15, 0);\
         \n  c16: rgb(0, 16, 0);\
         \n  c17: rgb(0, 17, 0);\
         \n  c18: rgb(0, 18, 0);\
         \n  c19: rgb(0, 19, 0);\
         \n  c20: rgb(0, 20, 0);\
         \n  c21: rgb(0, 21, 0);\
         \n  c22: rgb(0, 22, 0);\
         \n  c23: rgb(0, 23, 0);\
         \n  c24: rgb(0, 24, 0);\
         \n  c25: rgb(0, 25, 0);\
         \n  c26: rgb(0, 26, 0);\
         \n  c27: rgb(0, 27, 0);\
         \n  c28: rgb(0, 28, 0);\
         \n  c29: rgb(0, 29, 0);\
         \n  c30: rgb(0, 30, 0);\
         \n  c31: rgb(0, 31, 0);\
         \n  c32: rgb(0, 32, 0);\
         \n  c33: rgb(0, 33, 0);\
         \n  c34: rgb(0, 34, 0);\
         \n  c35: rgb(0, 35, 0);\
         \n  c36: rgb(0, 36, 0);\
         \n  c37: rgb(0, 37, 0);\
         \n  c38: rgb(0, 38, 0);\
         \n  c39: rgb(0, 39, 0);\
         \n  c40: rgb(0, 40, 0);\
         \n  c41: rgb(0, 41, 0);\
         \n  c42: rgb(0, 42, 0);\
         \n  c43: rgb(0, 43, 0);\
         \n  c44: rgb(0, 44, 0);\
         \n  c45: rgb(0, 45, 0);\
         \n  c46: rgb(0, 46, 0);\
         \n  c47: rgb(0, 47, 0);\
         \n  c48: rgb(0, 48, 0);\
         \n  c49: rgb(0, 49, 0);\
         \n  c50: rgb(0, 50, 0);\
         \n  c51: rgb(0, 51, 0);\
         \n  c52: rgb(0, 52, 0);\
         \n  c53: rgb(0, 53, 0);\
         \n  c54: rgb(0, 54, 0);\
         \n  c55: rgb(0, 55, 0);\
         \n  c56: rgb(0, 56, 0);\
         \n  c57: rgb(0, 57, 0);\
         \n  c58: rgb(0, 58, 0);\
         \n  c59: rgb(0, 59, 0);\
         \n  c60: rgb(0, 60, 0);\
         \n  c61: rgb(0, 61, 0);\
         \n  c62: rgb(0, 62, 0);\
         \n  c63: rgb(0, 63, 0);\
         \n  c64: rgb(0, 64, 0);\
         \n  c65: rgb(0, 65, 0);\
         \n  c66: rgb(0, 66, 0);\
         \n  c67: rgb(0, 67, 0);\
         \n  c68: rgb(0, 68, 0);\
         \n  c69: rgb(0, 69, 0);\
         \n  c70: rgb(0, 70, 0);\
         \n  c71: rgb(0, 71, 0);\
         \n  c72: rgb(0, 72, 0);\
         \n  c73: rgb(0, 73, 0);\
         \n  c74: rgb(0, 74, 0);\
         \n  c75: rgb(0, 75, 0);\
         \n  c76: rgb(0, 76, 0);\
         \n  c77: rgb(0, 77, 0);\
         \n  c78: rgb(0, 78, 0);\
         \n  c79: rgb(0, 79, 0);\
         \n  c80: rgb(0, 80, 0);\
         \n  c81: rgb(0, 81, 0);\
         \n  c82: rgb(0, 82, 0);\
         \n  c83: rgb(0, 83, 0);\
         \n  c84: rgb(0, 84, 0);\
         \n  c85: rgb(0, 85, 0);\
         \n  c86: rgb(0, 86, 0);\
         \n  c87: rgb(0, 87, 0);\
         \n  c88: rgb(0, 88, 0);\
         \n  c89: rgb(0, 89, 0);\
         \n  c90: rgb(0, 90, 0);\
         \n  c91: rgb(0, 91, 0);\
         \n  c92: rgb(0, 92, 0);\
         \n  c93: rgb(0, 93, 0);\
         \n  c94: rgb(0, 94, 0);\
         \n  c95: rgb(0, 95, 0);\
         \n  c96: rgb(0, 96, 0);\
         \n  c97: rgb(0, 97, 0);\
         \n  c98: rgb(0, 98, 0);\
         \n  c99: rgb(0, 99, 0);\
         \n  c100: rgb(0, 100, 0);\
         \n  c101: rgb(0, 101, 0);\
         \n  c102: rgb(0, 102, 0);\
         \n  c103: rgb(0, 103, 0);\
         \n  c104: rgb(0, 104, 0);\
         \n  c105: rgb(0, 105, 0);\
         \n  c106: rgb(0, 106, 0);\
         \n  c107: rgb(0, 107, 0);\
         \n  c108: rgb(0, 108, 0);\
         \n  c109: rgb(0, 109, 0);\
         \n  c110: rgb(0, 110, 0);\
         \n  c111: rgb(0, 111, 0);\
         \n  c112: rgb(0, 112, 0);\
         \n  c113: rgb(0, 113, 0);\
         \n  c114: rgb(0, 114, 0);\
         \n  c115: rgb(0, 115, 0);\
         \n  c116: rgb(0, 116, 0);\
         \n  c117: rgb(0, 117, 0);\
         \n  c118: rgb(0, 118, 0);\
         \n  c119: rgb(0, 119, 0);\
         \n  c120: rgb(0, 120, 0);\
         \n  c121: rgb(0, 121, 0);\
         \n  c122: rgb(0, 122, 0);\
         \n  c123: rgb(0, 123, 0);\
         \n  c124: rgb(0, 124, 0);\
         \n  c125: rgb(0, 125, 0);\
         \n  c126: rgb(0, 126, 0);\
         \n  c127: rgb(0, 127, 0);\
         \n  c128: rgb(0, 128, 0);\
         \n  c129: rgb(0, 129, 0);\
         \n  c130: rgb(0, 130, 0);\
         \n  c131: rgb(0, 131, 0);\
         \n  c132: rgb(0, 132, 0);\
         \n  c133: rgb(0, 133, 0);\
         \n  c134: rgb(0, 134, 0);\
         \n  c135: rgb(0, 135, 0);\
         \n  c136: rgb(0, 136, 0);\
         \n  c137: rgb(0, 137, 0);\
         \n  c138: rgb(0, 138, 0);\
         \n  c139: rgb(0, 139, 0);\
         \n  c140: rgb(0, 140, 0);\
         \n  c141: rgb(0, 141, 0);\
         \n  c142: rgb(0, 142, 0);\
         \n  c143: rgb(0, 143, 0);\
         \n  c144: rgb(0, 144, 0);\
         \n  c145: rgb(0, 145, 0);\
         \n  c146: rgb(0, 146, 0);\
         \n  c147: rgb(0, 147, 0);\
         \n  c148: rgb(0, 148, 0);\
         \n  c149: rgb(0, 149, 0);\
         \n  c150: rgb(0, 150, 0);\
         \n  c151: rgb(0, 151, 0);\
         \n  c152: rgb(0, 152, 0);\
         \n  c153: rgb(0, 153, 0);\
         \n  c154: rgb(0, 154, 0);\
         \n  c155: rgb(0, 155, 0);\
         \n  c156: rgb(0, 156, 0);\
         \n  c157: rgb(0, 157, 0);\
         \n  c158: rgb(0, 158, 0);\
         \n  c159: rgb(0, 159, 0);\
         \n  c160: rgb(0, 160, 0);\
         \n  c161: rgb(0, 161, 0);\
         \n  c162: rgb(0, 162, 0);\
         \n  c163: rgb(0, 163, 0);\
         \n  c164: rgb(0, 164, 0);\
         \n  c165: rgb(0, 165, 0);\
         \n  c166: rgb(0, 166, 0);\
         \n  c167: rgb(0, 167, 0);\
         \n  c168: rgb(0, 168, 0);\
         \n  c169: rgb(0, 169, 0);\
         \n  c170: rgb(0, 170, 0);\
         \n  c171: rgb(0, 171, 0);\
         \n  c172: rgb(0, 172, 0);\
         \n  c173: rgb(0, 173, 0);\
         \n  c174: rgb(0, 174, 0);\
         \n  c175: rgb(0, 175, 0);\
         \n  c176: rgb(0, 176, 0);\
         \n  c177: rgb(0, 177, 0);\
         \n  c178: rgb(0, 178, 0);\
         \n  c179: rgb(0, 179, 0);\
         \n  c180: rgb(0, 180, 0);\
         \n  c181: rgb(0, 181, 0);\
         \n  c182: rgb(0, 182, 0);\
         \n  c183: rgb(0, 183, 0);\
         \n  c184: rgb(0, 184, 0);\
         \n  c185: rgb(0, 185, 0);\
         \n  c186: rgb(0, 186, 0);\
         \n  c187: rgb(0, 187, 0);\
         \n  c188: rgb(0, 188, 0);\
         \n  c189: rgb(0, 189, 0);\
         \n  c190: rgb(0, 190, 0);\
         \n  c191: rgb(0, 191, 0);\
         \n  c192: rgb(0, 192, 0);\
         \n  c193: rgb(0, 193, 0);\
         \n  c194: rgb(0, 194, 0);\
         \n  c195: rgb(0, 195, 0);\
         \n  c196: rgb(0, 196, 0);\
         \n  c197: rgb(0, 197, 0);\
         \n  c198: rgb(0, 198, 0);\
         \n  c199: rgb(0, 199, 0);\
         \n  c200: rgb(0, 200, 0);\
         \n  c201: rgb(0, 201, 0);\
         \n  c202: rgb(0, 202, 0);\
         \n  c203: rgb(0, 203, 0);\
         \n  c204: rgb(0, 204, 0);\
         \n  c205: rgb(0, 205, 0);\
         \n  c206: rgb(0, 206, 0);\
         \n  c207: rgb(0, 207, 0);\
         \n  c208: rgb(0, 208, 0);\
         \n  c209: rgb(0, 209, 0);\
         \n  c210: rgb(0, 210, 0);\
         \n  c211: rgb(0, 211, 0);\
         \n  c212: rgb(0, 212, 0);\
         \n  c213: rgb(0, 213, 0);\
         \n  c214: rgb(0, 214, 0);\
         \n  c215: rgb(0, 215, 0);\
         \n  c216: rgb(0, 216, 0);\
         \n  c217: rgb(0, 217, 0);\
         \n  c218: rgb(0, 218, 0);\
         \n  c219: rgb(0, 219, 0);\
         \n  c220: rgb(0, 220, 0);\
         \n  c221: rgb(0, 221, 0);\
         \n  c222: rgb(0, 222, 0);\
         \n  c223: rgb(0, 223, 0);\
         \n  c224: rgb(0, 224, 0);\
         \n  c225: rgb(0, 225, 0);\
         \n  c226: rgb(0, 226, 0);\
         \n  c227: rgb(0, 227, 0);\
         \n  c228: rgb(0, 228, 0);\
         \n  c229: rgb(0, 229, 0);\
         \n  c230: rgb(0, 230, 0);\
         \n  c231: rgb(0, 231, 0);\
         \n  c232: rgb(0, 232, 0);\
         \n  c233: rgb(0, 233, 0);\
         \n  c234: rgb(0, 234, 0);\
         \n  c235: rgb(0, 235, 0);\
         \n  c236: rgb(0, 236, 0);\
         \n  c237: rgb(0, 237, 0);\
         \n  c238: rgb(0, 238, 0);\
         \n  c239: rgb(0, 239, 0);\
         \n  c240: rgb(0, 240, 0);\
         \n  c241: rgb(0, 241, 0);\
         \n  c242: rgb(0, 242, 0);\
         \n  c243: rgb(0, 243, 0);\
         \n  c244: rgb(0, 244, 0);\
         \n  c245: rgb(0, 245, 0);\
         \n  c246: rgb(0, 246, 0);\
         \n  c247: rgb(0, 247, 0);\
         \n  c248: rgb(0, 248, 0);\
         \n  c249: rgb(0, 249, 0);\
         \n  c250: rgb(0, 250, 0);\
         \n  c251: rgb(0, 251, 0);\
         \n  c252: rgb(0, 252, 0);\
         \n  c253: rgb(0, 253, 0);\
         \n  c254: rgb(0, 254, 0);\
         \n  c255: rgb(0, 255, 0);\
         \n  c256: rgb(0, 255, 0);\
         \n}\
         \nfoo {\
         \n  c-1: rgb(0, 0, 0);\
         \n  c0: rgb(0, 0, 0);\
         \n  c1: rgb(0, 2.55, 0);\
         \n  c2: rgb(0, 5.1, 0);\
         \n  c3: rgb(0, 7.65, 0);\
         \n  c4: rgb(0, 10.2, 0);\
         \n  c5: rgb(0, 12.75, 0);\
         \n  c6: rgb(0, 15.3, 0);\
         \n  c7: rgb(0, 17.85, 0);\
         \n  c8: rgb(0, 20.4, 0);\
         \n  c9: rgb(0, 22.95, 0);\
         \n  c10: rgb(0, 25.5, 0);\
         \n  c11: rgb(0, 28.05, 0);\
         \n  c12: rgb(0, 30.6, 0);\
         \n  c13: rgb(0, 33.15, 0);\
         \n  c14: rgb(0, 35.7, 0);\
         \n  c15: rgb(0, 38.25, 0);\
         \n  c16: rgb(0, 40.8, 0);\
         \n  c17: rgb(0, 43.35, 0);\
         \n  c18: rgb(0, 45.9, 0);\
         \n  c19: rgb(0, 48.45, 0);\
         \n  c20: rgb(0, 51, 0);\
         \n  c21: rgb(0, 53.55, 0);\
         \n  c22: rgb(0, 56.1, 0);\
         \n  c23: rgb(0, 58.65, 0);\
         \n  c24: rgb(0, 61.2, 0);\
         \n  c25: rgb(0, 63.75, 0);\
         \n  c26: rgb(0, 66.3, 0);\
         \n  c27: rgb(0, 68.85, 0);\
         \n  c28: rgb(0, 71.4, 0);\
         \n  c29: rgb(0, 73.95, 0);\
         \n  c30: rgb(0, 76.5, 0);\
         \n  c31: rgb(0, 79.05, 0);\
         \n  c32: rgb(0, 81.6, 0);\
         \n  c33: rgb(0, 84.15, 0);\
         \n  c34: rgb(0, 86.7, 0);\
         \n  c35: rgb(0, 89.25, 0);\
         \n  c36: rgb(0, 91.8, 0);\
         \n  c37: rgb(0, 94.35, 0);\
         \n  c38: rgb(0, 96.9, 0);\
         \n  c39: rgb(0, 99.45, 0);\
         \n  c40: rgb(0, 102, 0);\
         \n  c41: rgb(0, 104.55, 0);\
         \n  c42: rgb(0, 107.1, 0);\
         \n  c43: rgb(0, 109.65, 0);\
         \n  c44: rgb(0, 112.2, 0);\
         \n  c45: rgb(0, 114.75, 0);\
         \n  c46: rgb(0, 117.3, 0);\
         \n  c47: rgb(0, 119.85, 0);\
         \n  c48: rgb(0, 122.4, 0);\
         \n  c49: rgb(0, 124.95, 0);\
         \n  c50: rgb(0, 127.5, 0);\
         \n  c51: rgb(0, 130.05, 0);\
         \n  c52: rgb(0, 132.6, 0);\
         \n  c53: rgb(0, 135.15, 0);\
         \n  c54: rgb(0, 137.7, 0);\
         \n  c55: rgb(0, 140.25, 0);\
         \n  c56: rgb(0, 142.8, 0);\
         \n  c57: rgb(0, 145.35, 0);\
         \n  c58: rgb(0, 147.9, 0);\
         \n  c59: rgb(0, 150.45, 0);\
         \n  c60: rgb(0, 153, 0);\
         \n  c61: rgb(0, 155.55, 0);\
         \n  c62: rgb(0, 158.1, 0);\
         \n  c63: rgb(0, 160.65, 0);\
         \n  c64: rgb(0, 163.2, 0);\
         \n  c65: rgb(0, 165.75, 0);\
         \n  c66: rgb(0, 168.3, 0);\
         \n  c67: rgb(0, 170.85, 0);\
         \n  c68: rgb(0, 173.4, 0);\
         \n  c69: rgb(0, 175.95, 0);\
         \n  c70: rgb(0, 178.5, 0);\
         \n  c71: rgb(0, 181.05, 0);\
         \n  c72: rgb(0, 183.6, 0);\
         \n  c73: rgb(0, 186.15, 0);\
         \n  c74: rgb(0, 188.7, 0);\
         \n  c75: rgb(0, 191.25, 0);\
         \n  c76: rgb(0, 193.8, 0);\
         \n  c77: rgb(0, 196.35, 0);\
         \n  c78: rgb(0, 198.9, 0);\
         \n  c79: rgb(0, 201.45, 0);\
         \n  c80: rgb(0, 204, 0);\
         \n  c81: rgb(0, 206.55, 0);\
         \n  c82: rgb(0, 209.1, 0);\
         \n  c83: rgb(0, 211.65, 0);\
         \n  c84: rgb(0, 214.2, 0);\
         \n  c85: rgb(0, 216.75, 0);\
         \n  c86: rgb(0, 219.3, 0);\
         \n  c87: rgb(0, 221.85, 0);\
         \n  c88: rgb(0, 224.4, 0);\
         \n  c89: rgb(0, 226.95, 0);\
         \n  c90: rgb(0, 229.5, 0);\
         \n  c91: rgb(0, 232.05, 0);\
         \n  c92: rgb(0, 234.6, 0);\
         \n  c93: rgb(0, 237.15, 0);\
         \n  c94: rgb(0, 239.7, 0);\
         \n  c95: rgb(0, 242.25, 0);\
         \n  c96: rgb(0, 244.8, 0);\
         \n  c97: rgb(0, 247.35, 0);\
         \n  c98: rgb(0, 249.9, 0);\
         \n  c99: rgb(0, 252.45, 0);\
         \n  c100: rgb(0, 255, 0);\
         \n  c101: rgb(0, 255, 0);\
         \n}\n"
    );
}
